# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), 
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.9] - 2023-10-24
### Added
- Support the command `--output-file` to write the statistics into a file

## [0.0.1] - 2023-10-18
### Added
- Initial import
